return {
  'saghen/blink.cmp',
  lazy = false, -- lazy loading handled internally
  -- optional: provides snippets for the snippet source
  dependencies = {
    'rafamadriz/friendly-snippets',
    'giuxtaposition/blink-cmp-copilot',
    {
      'fang2hou/blink-copilot',
      opts = {
        max_completions = 1, -- Global default for max completions
        max_attempts = 2, -- Global default for max attempts
        -- `kind` is not set, so the default value is "Copilot"
      },
    },
    'dmitmel/cmp-cmdline-history',
    'onsails/lspkind.nvim',
    'folke/lazydev.nvim',
    'L3MON4D3/LuaSnip',
    {
      'saghen/blink.compat',
      -- use the latest release, via version = '*', if you also use the latest release for blink.cmp
      version = '*',
      -- lazy.nvim will automatically load the plugin when it's required by blink.cmp
      lazy = true,
      -- make sure to set opts so that lazy.nvim calls blink.compat's setup
      opts = {},
    },
    'rcarriga/cmp-dap',
  },

  -- use a release tag to download pre-built binaries
  version = '*',
  -- OR build from source, requires nightly: https://rust-lang.github.io/rustup/concepts/channels.html#working-with-nightly-rust
  -- build = 'cargo build --release',
  -- If you use nix, you can build from source using latest nightly rust with:
  -- build = 'nix run .#build-plugin',

  opts = {
    -- 'default' for mappings similar to built-in completion
    -- 'super-tab' for mappings similar to vscode (tab to accept, arrow keys to navigate)
    -- 'enter' for mappings similar to 'super-tab' but with 'enter' to accept
    -- see the "default configuration" section below for full documentation on how to define
    -- your own keymap.
    keymap = { preset = 'enter' },

    appearance = {
      -- Sets the fallback highlight groups to nvim-cmp's highlight groups
      -- Useful for when your theme doesn't support blink.cmp
      -- will be removed in a future release
      use_nvim_cmp_as_default = true,
      -- Set to 'mono' for 'Nerd Font Mono' or 'normal' for 'Nerd Font'
      -- Adjusts spacing to ensure icons are aligned
      nerd_font_variant = 'mono',
    },

    enabled = function() return (vim.bo.buftype ~= 'prompt' and vim.b.completion ~= false) or require('cmp_dap').is_dap_buffer() end,
    -- default list of enabled providers defined so that you can extend it
    -- elsewhere in your config, without redefining it, via `opts_extend`
    sources = {
      default = { 'copilot', 'lazydev', 'lsp', 'path', 'snippets', 'buffer', 'codeium' },

      per_filetype = {
        ['dap-repl'] = {
          'copilot',
          'dap',
          'snippets',
          'path',
          'buffer',
        },
      },

      providers = {
        copilot = {
          name = 'copilot',
          module = 'blink-copilot',
          score_offset = 100,
          async = true,
          opts = {
            -- Local options override global ones
            -- Final settings: max_completions = 3, max_attempts = 2, kind = "Copilot"
            max_completions = 3, -- Override global max_completions
          },
        },
        lazydev = {
          name = 'LazyDev',
          module = 'lazydev.integrations.blink',
          -- make lazydev completions top priority (see `:h blink.cmp`)
          score_offset = 100,
        },
        codeium = { -- TODO: Replace with https://github.com/Exafunction/codeium.nvim/pull/264
          name = 'codeium', -- IMPORTANT: use the same name as you would for nvim-cmp
          module = 'blink.compat.source',
          async = true,
        },
        cmdline_history = {
          name = 'cmdline_history',
          module = 'blink.compat.source',
          score_offset = -50,
        },
        dap = {
          name = 'dap',
          module = 'blink.compat.source',
          async = false,
          enabled = function() return require('cmp_dap').is_dap_buffer() end,
        },
        buffer = {
          name = 'Buffer',
          module = 'blink.cmp.sources.buffer',
          opts = {
            -- default to all visible buffers
            get_bufnrs = function()
              return vim
                .iter(vim.api.nvim_list_wins())
                :map(function(win) return vim.api.nvim_win_get_buf(win) end)
                :filter(function(buf) return vim.bo[buf].buftype ~= 'nofile' end)
                :totable()
            end,
          },
        },
      },
    },

    cmdline = {
      sources = function()
        local type = vim.fn.getcmdtype()
        -- Search forward and backward
        if type == '/' or type == '?' then
          return { 'buffer' }
        end
        -- Commands
        if type == ':' or type == '@' then
          return { 'cmdline', 'buffer', 'cmdline_history' }
        end
        return {}
      end,
      completion = {
        trigger = {
          show_on_blocked_trigger_characters = {},
          show_on_x_blocked_trigger_characters = nil, -- Inherits from top level `completion.trigger.show_on_blocked_trigger_characters` config when not set
        },
        list = {
          selection = {
            auto_insert = false,
            preselect = false,
          },
        },
        menu = {
          auto_show = true, -- Inherits from top level `completion.menu.auto_show` config when not set
        },
      },
      keymap = {
        ['<down>'] = { 'select_next', 'fallback' },
        ['<up>'] = { 'select_prev', 'fallback' },
        ['<CR>'] = { 'accept', 'fallback' },
        ['<C-e>'] = { 'cancel' },
      },
    },

    completion = {
      list = {
        selection = {
          auto_insert = false,
          preselect = false,
        },
      },
      accept = {
        dot_repeat = false,
      },
      menu = {
        max_height = 25,
        draw = {
          padding = 1,
          gap = 1,
          -- treesitter = { 'lsp' },
          components = {
            kind_icon = {
              ellipsis = false,
              text = function(ctx)
                local lspkind = require('lspkind')
                local icon = ctx.kind_icon
                if ctx.source_name == 'cmdline_history' then
                  icon = require('nvim-web-devicons').get_icon('log')
                elseif vim.tbl_contains({ 'Path' }, ctx.source_name) then
                  local dev_icon, _ = require('nvim-web-devicons').get_icon(ctx.label)
                  if dev_icon then
                    icon = dev_icon
                  end
                else
                  icon = lspkind.symbolic(ctx.kind, {
                    mode = 'symbol',
                  })
                end

                return icon .. ctx.icon_gap
              end,

              -- Optionally, use the highlight groups from nvim-web-devicons
              -- You can also add the same function for `kind.highlight` if you want to
              -- keep the highlight groups in sync with the icons.
              highlight = function(ctx)
                local hl = ctx.kind_hl
                if ctx.source_name == 'cmdline_history' then
                  _, hl = require('nvim-web-devicons').get_icon('log')
                elseif ctx.source_name == 'cmdline' then
                  _, hl = require('nvim-web-devicons').get_icon('cc')
                elseif vim.tbl_contains({ 'Path' }, ctx.source_name) then
                  local dev_icon, dev_hl = require('nvim-web-devicons').get_icon(ctx.label)
                  if dev_icon then
                    hl = dev_hl
                  end
                end
                return hl
              end,
            },
          },
        },
      },
      documentation = {
        auto_show = true,
        auto_show_delay_ms = 500,
        treesitter_highlighting = true,
      },
    },

    -- experimental signature help support
    signature = { enabled = true },
    snippets = {
      preset = 'luasnip',
    },
  },
  -- allows extending the providers array elsewhere in your config
  -- without having to redefine it
  enabled = false,
}
